native_storage_utility library
Functions
-
getFreeBytes(
String path) → int - Number of bytes available in storage.
-
getTotalBytes(
String path) → int - The total number of bytes supported by the storage.
-
openDirectory(
String path) → void - Open native directory via calling channel defined on platform interface
-
openFile(
String path) → void